@@ -1,3 +1,14 @@
+#
+# $Id:$
+#
+# This file is part of the Cloud Services Integration Platform (CSIP),
+# a Model-as-a-Service framework, API, and application suite.
+#
+# 2012-2020, OMSLab, Colorado State University.
+#
+# OMSLab licenses this file to you under the MIT license.
+# See the LICENSE file in the project root for more information.
+#
 import requests
 import numpy as np
 import json
@@ -13,7 +24,7 @@ NORM = {
 }
 
 
-def get_cost(response, objfunc):
+def calc_cost(response, objfunc):
     """aggregated objective function value -> cost"""
     cost = 0.0
     for of in objfunc:
